@@ -1,5 +1,8 @@
 package Plack::Middleware::PeriAHS::LogAccess;
 
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.60'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -12,14 +15,12 @@ use Plack::Util::Accessor qw(
                                 max_resp_len
                         );
 
-use JSON;
+use JSON::MaybeXS;
 use Plack::Util;
 use POSIX;
 use Scalar::Util qw(blessed);
 use Time::HiRes qw(gettimeofday tv_interval);
 
-our $VERSION = '0.59'; # VERSION
-
 sub prepare_app {
     my $self = shift;
     if (!$self->dest) {
@@ -69,7 +70,7 @@ sub log_access {
         $server_addr = "tcp:$env->{SERVER_PORT}";
     }
 
-    state $json = JSON->new->allow_nonref->allow_blessed->convert_blessed;
+    state $json = JSON::MaybeXS->new->allow_nonref->allow_blessed->convert_blessed;
     local *UNIVERSAL::TO_JSON = sub { "$_[0]" };
 
     my $rreq = $env->{'riap.request'};
@@ -203,7 +204,7 @@ Plack::Middleware::PeriAHS::LogAccess - Log request
 
 =head1 VERSION
 
-This document describes version 0.59 of Plack::Middleware::PeriAHS::LogAccess (from Perl distribution Perinci-Access-HTTP-Server), released on 2015-09-03.
+This document describes version 0.60 of Plack::Middleware::PeriAHS::LogAccess (from Perl distribution Perinci-Access-HTTP-Server), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -271,7 +272,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Server>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Server>.
 
 =head1 BUGS
 
@@ -287,7 +288,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
