@@ -1,7 +1,7 @@
 package Plack::Middleware::PeriAHS::ParseRequest;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.59'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.60'; # VERSION
 
 use 5.010;
 use strict;
@@ -43,11 +43,11 @@ use URI::Escape;
 # retun ($success?, $errmsg, $res)
 sub __parse_json {
     require Data::Clean::FromJSON;
-    require JSON;
+    require JSON::MaybeXS;
 
     my $str = shift;
 
-    state $json = JSON->new->allow_nonref;
+    state $json = JSON::MaybeXS->new->allow_nonref;
 
     # to rid of those JSON::XS::Boolean objects which currently choke
     # Data::Sah-generated validator code. in the future Data::Sah can be
@@ -451,7 +451,7 @@ Plack::Middleware::PeriAHS::ParseRequest - Parse Riap request from HTTP request
 
 =head1 VERSION
 
-This document describes version 0.59 of Plack::Middleware::PeriAHS::ParseRequest (from Perl distribution Perinci-Access-HTTP-Server), released on 2015-09-03.
+This document describes version 0.60 of Plack::Middleware::PeriAHS::ParseRequest (from Perl distribution Perinci-Access-HTTP-Server), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -703,17 +703,13 @@ metadata.
 
 =back
 
-=head1 SEE ALSO
-
-L<Perinci::Access::HTTP::Server>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Access-HTTP-Server>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Server>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Server>.
 
 =head1 BUGS
 
@@ -723,13 +719,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::Access::HTTP::Server>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
