@@ -1,5 +1,8 @@
 package Plack::Util::PeriAHS;
 
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.60'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -8,11 +11,9 @@ use Log::Any '$log';
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(errpage);
 
-our $VERSION = '0.59'; # VERSION
+use JSON::MaybeXS;
 
-use JSON;
-
-my $json = JSON->new->allow_nonref;
+my $json = JSON::MaybeXS->new->allow_nonref;
 
 sub errpage {
     my ($env, $rres) = @_;
@@ -60,7 +61,7 @@ Plack::Util::PeriAHS - Utility routines
 
 =head1 VERSION
 
-This document describes version 0.59 of Plack::Util::PeriAHS (from Perl distribution Perinci-Access-HTTP-Server), released on 2015-09-03.
+This document describes version 0.60 of Plack::Util::PeriAHS (from Perl distribution Perinci-Access-HTTP-Server), released on 2016-03-16.
 
 =head1 FUNCTIONS
 
@@ -78,7 +79,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-HTTP-Server>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-HTTP-Server>.
 
 =head1 BUGS
 
@@ -94,7 +95,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
